/* This file is part of GPump, a Pump.io client.
 *
 * GPump (THE SOFTWARE) is made available under the terms and conditions of the
 * GNU Lesser General Public Licence 3.0. A copy of the licence can be read
 * in the file lgpl-3.0.txt in the root of this project.
 */

const Gio = imports.gi.Gio;
const Gst = imports.gi.Gst;
const GLib = imports.gi.GLib;
const Gtk = imports.gi.Gtk;
const Lang = imports.lang;

const SettingsData = imports.settings_data;

const Application = new Lang.Class ({
  Name: "Application",
  
  _init: function () {
    this.application = new Gtk.Application ({
      application_id: "org.gego.gpump",
      flags: Gio.ApplicationFlags.FLAGS_NONE,
      register_session: true
    });
    this.application.connect('activate', Lang.bind(this, this._on_activate));
  },
  
  _on_activate: function () {
    /* Guarantee that only one window is present at any time. */
    let w_list = this.application.get_windows ();
    if (w_list.length) {
      w_list[0].present ();
      return;
    }
    
    this._prepareWindow ();
    this._prepareAppMenu ();
    this._prepareHeaderBar ();
    
    this.window.show_all ();
  },
  
  /**
   * This function is used to prepare the window, it also initializes and adds
   * the headerbar to it.
   */
  _prepareWindow: function () {
    this.window = new Gtk.Window ({
      type: Gtk.WindowType.TOPLEVEL,
      title: 'GPump',
      default_height: 500,
      default_width: 500,
      height_request: 500,
      width_request: 500
    });
    
    this.window.set_titlebar ((this.headerbar = new Gtk.HeaderBar({
      title: 'GPump',
      subtitle: 'A Pump.io client',
      show_close_button: true
    })));
    
    this.window.add (( this.scroll_view = new Gtk.ScrolledWindow () ));
    this.scroll_view.add ((this.list_box = new Gtk.ListBox ()));
    
    this.window.connect ('delete_event',
                         Lang.bind (this.window,
                                    this.window.hide_on_delete));
    
    this.application.add_window (this.window);
  },
  
  /**
   * This function is used to create the application menu.
   */
  _prepareAppMenu: function () {
    let menu = new Gio.Menu ();
    let section = new Gio.Menu ();
    
    section.append ("Preferences", "app.preferences");
    menu.append_section (null, section);
    
    section = new Gio.Menu ();
    section.append ("About", "app.about");
    section.append ("Quit", "app.quit");
    menu.append_section (null, section);
    
    this.application.set_app_menu (menu);
    
    let quit_action = new Gio.SimpleAction ({name: "quit"});
    quit_action.connect ('activate', Lang.bind (this, function () {
      this.application.quit ();
    }));
    this.application.add_action (quit_action);
    
  },
  
  /**
   * This function is used to prepare the hearderbar by adding buttons and
   * assigning callback functions to them.
   */
  _prepareHeaderBar: function () {
    this.headerbar.pack_start ((this.new_post_btn = new Gtk.Button ({
      image: (new Gtk.Image ({icon_name: 'text-editor-symbolic'})),
      tooltip_text: 'Create new post'
    })));
    
    this.headerbar.pack_start ((this.refresh_btn = new Gtk.Button({
      image: (new Gtk.Image ({icon_name: 'emblem-synchronizing-symbolic'})),
      tooltip_text: 'Refresh the stream'
    })));
    
    this.headerbar.pack_end ((this.user_menu_btn = new Gtk.Button ({
      image: (new Gtk.Image ({icon_name: 'emblem-system-symbolic'})),
      tooltip_text: 'Switch and manage users'
    })));
  }
  
});
